VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "clsPrint"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'==============================================================================
'Kapselt den Druck eines ListViews ab.
'
'Scope:     DLL-ffentlich erstellbar.
'==============================================================================


Option Explicit

Dim MyListView As ListView 'zu druckendes ListView

Dim PageProperties As New CPage 'Seiteneigenschaften

'Titel, Kopf- und Fuzeile
Dim mTitle As New CText, mHeader As New CText, mFooter As New CText

'Schriftart der Eintrge
Dim mFont As New StdFont

'In Farbe drucken, Ausgewhlte Eintrge markieren, Nur ausgewhlte Eintrge drucken.
Dim mInColor As Boolean, mMark As Boolean, mOnlySelected As Boolean

Dim Pages As Long 'Aktuelle Anzahl gedruckter Seiten

'Objekt, dass das eigentliche Drucken des ListViews bernimmt.
Dim WithEvents LVPrinter As CPrintListView
Attribute LVPrinter.VB_VarHelpID = -1

'Gibt das Printer-Objekt dieser DLL-Instanz zurck, da andere DLLs eine eigenes Objekt
'mit anderen Eigenschaften haben (knnen).
Property Get MyPrinter() As Object
    Set MyPrinter = Printer
End Property

'==============================================================================
'Zweck:     Zeigt den Dialog zum Auswhlen und Konfigurieren eines Druckers an.
'
'Rckgabe:  True, falls der Dialog besttigt wurde, sonst False.
'==============================================================================
Function ShowPrintDialog() As Boolean
    With New frmCDialogDummy
        With .cdialog
            .Flags = cdlPDNoSelection
            On Error GoTo erro
            .ShowPrinter
        End With
    End With
    ShowPrintDialog = True
erro:
End Function

'==============================================================================
'Zweck:     Zeigt den Dialog zum Setzen der Seiteneigenschaften an.
'
'Rckgabe:  True, falls der Dialog besttigt wurde, sonst False.
'==============================================================================
Function ShowPageSetupDialog() As Boolean
    With PageProperties
        Dim LeftMargin As Long, RightMargin As Long, TopMargin As Long, BottomMargin As Long
        LeftMargin = .LeftMargin
        RightMargin = .RightMargin
        TopMargin = .TopMargin
        BottomMargin = .BottomMargin

        Dim PaperSize As Long, Orientation As Long
        PaperSize = .PaperSize
        Orientation = .Orientation


        'Todo: Show PageSetup-Dialog, maybe see www.vbaccelerator.com for this dialog

        .LeftMargin = LeftMargin
        .RightMargin = RightMargin
        .TopMargin = TopMargin
        .BottomMargin = BottomMargin
        .Orientation = Orientation
        .PaperSize = PaperSize
        ShowPageSetupDialog = True
    End With
End Function

'==============================================================================
'Zweck:     Zeigt den Dialog zum Auswhlen der Schriftart fr Eintrge an.
'
'Rckgabe:  True, falls der Dialog besttigt wurde, sonst False.
'==============================================================================
Function ShowFontDialog() As Boolean
    With New frmCDialogDummy
        With .cdialog
            .Flags = &H100
            .FontBold = mFont.Bold
            .FontItalic = mFont.Italic
            .FontName = mFont.Name
            .FontSize = mFont.Size
            .FontStrikethru = mFont.Strikethrough
            .FontUnderline = mFont.Underline
            
            .Flags = cdlCFBoth
            
            On Error GoTo erro
            .ShowFont
            
            mFont.Bold = .FontBold
            mFont.Italic = .FontItalic
            mFont.Name = .FontName
            mFont.Size = .FontSize
            mFont.Strikethrough = .FontStrikethru
            mFont.Underline = .FontUnderline
        
erro:
        End With
    End With
End Function

'==============================================================================
'Zweck:     Setzt das zu druckende ListView. Die Schriftart die verwendet
'           wird um die ListView-Eintrge zu drucken wird automatisch aus dem
'           ListView ermittelt.
'
'Parameter: - ListView      Zu druckendes ListView.
'==============================================================================
Property Let ListView(ListView As Object)
    Set MyListView = ListView
    
    Set mFont = New StdFont
    With mFont
        .Name = MyListView.Font.Name
        .Size = MyListView.Font.Size
        .Bold = MyListView.Font.Bold
        .Italic = MyListView.Font.Italic
        .Strikethrough = MyListView.Font.Strikethrough
        .Underline = MyListView.Font.Underline
    End With
End Property

'Die folgenden Eigenschaften ermglichen das Auslesen bzw. Setzen der
'Druck-Attribute.

Property Get ListView() As Object
    Set ListView = MyListView
End Property

Property Get Title() As CText
    Set Title = mTitle
End Property

Property Get Header() As CText
    Set Header = mHeader
End Property

Property Get Footer() As CText
    Set Footer = mFooter
End Property

Property Get Font() As StdFont
    Set Font = mFont
End Property

Property Get InColor() As Boolean
    InColor = mInColor
End Property

Property Let InColor(ByVal value As Boolean)
    mInColor = value
End Property

Property Get Mark() As Boolean
    Mark = mMark
End Property

Property Let Mark(ByVal value As Boolean)
    mMark = value
End Property

Property Get OnlySelected() As Boolean
    OnlySelected = mOnlySelected
End Property

Property Let OnlySelected(ByVal value As Boolean)
    mOnlySelected = OnlySelected
End Property

'==============================================================================
'Zweck:     Druckt das zurvor angegebenen ListView mit den zuvor angegebenen
'           Attributen auf dem gewhlten Drucker aus.
'
'Rckgabe:  True, falls der Vorgang erfolgreich war, sonst False.
'==============================================================================
Function PrintListView() As Boolean
    Set LVPrinter = New CPrintListView
    With LVPrinter
        Set .Control = MyListView
        Set .FontItem = mFont
        Set .Title = mTitle
        
        Set .Page = PageProperties
        .Page.Header.Alignment = mHeader.Alignment
        Set .Page.Header.Font = mHeader.Font
        
        .Page.Footer.Alignment = mFooter.Alignment
        Set .Page.Footer.Font = mFooter.Font
        
        Pages = 0
        
        .PrintOnlySelectedItems = mOnlySelected
        
        PrintListView = .PrintControl(mInColor, mMark)
        
    End With
End Function

Private Sub Class_Initialize()
    InColor = True
    Header.Text = "gedruckt am %datetime%"
    Header.Alignment = vbCenter
    Header.Font.Size = 8
    
    Title.Alignment = vbCenter
    Title.Font.Size = 22
    Title.Font.Bold = True
    
    Footer.Text = "Seite %page%"
    Footer.Alignment = vbRightJustify
    Footer.Font.Size = 8
End Sub

'Tritt auf, wenn eine neue Seite beginnt.
Private Sub LVPrinter_BeforeNewPage()
    'Hier werden Kopf- und Fuzeilen aktualisiert.
    Pages = Pages + 1
    LVPrinter.Page.Header.Text = Replace(mHeader.Text, "%page%", Pages)
    LVPrinter.Page.Footer.Text = Replace(mFooter.Text, "%page%", Pages)
    LVPrinter.Page.Header.Text = Replace(LVPrinter.Page.Header.Text, "%datetime%", Format(Now, "dddd, d. mmmm yyyy, hh:nn"))
    LVPrinter.Page.Footer.Text = Replace(LVPrinter.Page.Footer.Text, "%datetime%%", Format(Now, "dddd, d. mmmm yyyy, hh:nn"))
End Sub
